Tax class

Constructors

Tax({required int amount, required int percentage, required TaxType type})
Tax.fromJson(String source)
factory
Tax.fromMap(Map<String, dynamic> map)
factory

Properties

amount int
final
hashCode int
The hash code for this object.
no setteroverride
percentage int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TaxType
final

Methods

copyWith({int? amount, int? percentage, TaxType? type}) Tax
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override