Company class

Constructors

Company({required String id, String? vatId, required String poDetails})
const
Company.fromJson(String source)
factory
Company.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
poDetails String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vatId String?
final

Methods

copyWith({String? id, String? vatId, String? poDetails}) Company
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited