Customer class

Constructors

Customer({Person? person, Billing? billing})
Customer.fromJson(String source)
factory
Customer.fromMap(Map<String, dynamic> map)
factory

Properties

billing Billing?
final
hashCode int
The hash code for this object.
no setteroverride
person Person?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Person? person, Billing? billing}) Customer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override