Person class

Constructors

Person({required String id, Name? nmae, String? email, Phone? phone, String? birthdate, String? personalNumber, String? coordinationNumber, String? gdNumber, String? countryResidence, bool? isPep, bool? isSancyioned})
Person.fromJson(String source)
factory
Person.fromMap(Map<String, dynamic> map)
factory

Properties

birthdate String?
final
coordinationNumber String?
final
countryResidence String?
final
email String?
final
gdNumber String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
isPep bool?
final
isSancyioned bool?
final
nmae Name?
final
personalNumber String?
final
phone Phone?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, Name? nmae, String? email, Phone? phone, String? birthdate, String? personalNumber, String? coordinationNumber, String? gdNumber, String? countryResidence, bool? isPep, bool? isSancyioned}) Person
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override