OrderDetails class
Constructors
- OrderDetails({required String orderId, required String paymentMethod, required String paymentStatus, AdditionalDetails? data})
- OrderDetails.fromJson(String source)
-
factory
-
OrderDetails.fromMap(Map<
String, dynamic> map) -
factory
Properties
- data ↔ AdditionalDetails?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- orderId ↔ String
-
getter/setter pair
- paymentMethod ↔ String
-
getter/setter pair
- paymentStatus ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? orderId, String? paymentMethod, String? paymentStatus, AdditionalDetails? data}) → OrderDetails -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant OrderDetails other) → bool -
The equality operator.
override