PaymentDetails class

Constructors

PaymentDetails({required String id, required String orderId, required String paymentId, required String type, required String method, required String amount, required String? payee, required String currency, required String timestamp, String? description, String? gatewayResponseCode, String? externalTerminalId, String? externalMerchantId, String? responseCode, String? rrn, String? truncatedPan, String? startOfPan, String? applicationId, String? applicationNameOrLabel, String? cardAcceptorId, String? cardAcceptorTerminalId, String? entryMode, String? lastCvmUsed, String? originalTransactionId, String? panSequenceNumber, String? reversalAuthorisationCode, String? reversalRequestedOnLocal, String? terminalVerificationResults, String? statusInformation, String? voidRequestedOnLocal, String? reversalOn, String? completionCryptogram, String? pinStatement, required String status, String? authCode, List<String>? eRefs, String? userMessageId, String? terminalMessageCode})
PaymentDetails.fromJson(String source)
factory
PaymentDetails.fromMap(Map<String, dynamic> map)
factory

Properties

amount String
final
applicationId String?
final
applicationNameOrLabel String?
final
authCode String?
final
cardAcceptorId String?
final
cardAcceptorTerminalId String?
final
completionCryptogram String?
final
currency String
final
description String?
final
entryMode String?
final
eRefs List<String>?
final
externalMerchantId String?
final
externalTerminalId String?
final
gatewayResponseCode String?
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
lastCvmUsed String?
final
method String
final
orderId String
final
originalTransactionId String?
final
panSequenceNumber String?
final
payee String?
final
paymentId String
final
pinStatement String?
final
responseCode String?
final
reversalAuthorisationCode String?
final
reversalOn String?
final
reversalRequestedOnLocal String?
final
rrn String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startOfPan String?
final
status String
final
statusInformation String?
final
terminalMessageCode String?
final
terminalVerificationResults String?
final
timestamp String
final
truncatedPan String?
final
type String
final
userMessageId String?
final
voidRequestedOnLocal String?
final

Methods

copyWith({String? id, String? orderId, String? paymentId, String? type, String? method, String? amount, String? payee, String? currency, String? timestamp, String? description, String? gatewayResponseCode, String? externalTerminalId, String? externalMerchantId, String? responseCode, String? rrn, String? truncatedPan, String? startOfPan, String? applicationId, String? applicationNameOrLabel, String? cardAcceptorId, String? cardAcceptorTerminalId, String? entryMode, String? lastCvmUsed, String? originalTransactionId, String? panSequenceNumber, String? reversalAuthorisationCode, String? reversalRequestedOnLocal, String? terminalVerificationResults, String? statusInformation, String? voidRequestedOnLocal, String? reversalOn, String? completionCryptogram, String? pinStatement, String? status, String? authCode, List<String>? eRefs, String? userMessageId, String? terminalMessageCode}) PaymentDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(covariant PaymentDetails other) bool
The equality operator.
override