GetRegistrationIdResponse class
Constructors
- GetRegistrationIdResponse({required RegistrationId data})
- GetRegistrationIdResponse.fromJson(String source)
-
factory
-
GetRegistrationIdResponse.fromMap(Map<
String, dynamic> map) -
factory
Properties
- data → RegistrationId
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{RegistrationId? data}) → GetRegistrationIdResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override