RegistrationId class
Constructors
- RegistrationId({required String registrationCodeId, required String entryCode})
- RegistrationId.fromJson(String source)
-
factory
-
RegistrationId.fromMap(Map<
String, dynamic> map) -
factory
Properties
- entryCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- registrationCodeId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? registrationCodeId, String? entryCode}) → RegistrationId -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override