PaymentInitiated class

Constructors

PaymentInitiated({required Payment data})
PaymentInitiated.fromJson(String source)
factory
PaymentInitiated.fromMap(Map<String, dynamic> map)
factory

Properties

data Payment
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Payment? data}) PaymentInitiated
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override