SurfboardTTP class
SurfboardTTP deals the setting up of this SDK and make it ready to perform desirable operations
Constructors
- SurfboardTTP({required String apiUrl, String? terminalId, required String ttpBundleId, required String partnerId, required String merchantId, required String storeId, required String appId, HttpService? httpService})
Properties
- apiUrl → String
-
API URl of the environment you are connecting to. The API URL is available as part
of the setup process
final
- appId → String
-
The app identifier to your pos app. This is received by providing the package name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantId → String
-
The merchant ID for each merchant. This is received after the completion of the onboarding
process.
final
- partnerId → String
-
You receive this ID as part of the setup process
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeId → String
-
The storeID of the merchant. This is received after the completion of the onboarding process.
You can also create additional stores to get a new storeId.
final
- terminalId → String?
-
TerminalId of the particular device. Which is obtained from the terminal registration process.
If the terminal is already registered, you need to pass in the terminalId to avoid a trigger
of the re-registration process.
final
- ttpBundleId → String
-
packageName or application Id of the ttp app.
The bundleId should be passed respective to the environment. This information is provided
as part of the setup process.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAuthToken(
{required String authToken}) → dynamic - Sets the authToken generated by the authToken api. And this method has to be called everytime when the token is expired.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited