OrderDetails class
Constructors
-
OrderDetails({String? purchaseOrderId, bool? companyPurchase, Company? company, Customer? customer, required OrderType type, String? referenceId, List<
LineItem> ? orderLines, ItemAmount? totalOrderAmount}) - OrderDetails.fromJson(String source)
-
factory
-
OrderDetails.fromMap(Map<
String, dynamic> map) -
factory
Properties
- company → Company?
-
final
- companyPurchase → bool?
-
final
- customer → Customer?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
orderLines
↔ List<
LineItem> ? -
getter/setter pair
- purchaseOrderId → String?
-
final
- referenceId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminalId → String
-
final
- totalOrderAmount ↔ ItemAmount?
-
getter/setter pair
- type → OrderType
-
final
Methods
-
copyWith(
{String? purchaseOrderId, bool? companyPurchase, Company? company, Customer? customer, OrderType? type, String? referenceId, List< LineItem> ? orderLines, ItemAmount? totalOrderAmount}) → OrderDetails -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override