PaymentDetailsData class
Constructors
- PaymentDetailsData({required PaymentStatusDetails paymentStatus, required TransactionDetails? transaction})
- PaymentDetailsData.fromJson(String source)
-
factory
-
PaymentDetailsData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- paymentStatus ↔ PaymentStatusDetails
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction ↔ TransactionDetails?
-
getter/setter pair
Methods
-
copyWith(
{PaymentStatusDetails? paymentStatus, TransactionDetails? transaction}) → PaymentDetailsData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant PaymentDetailsData other) → bool -
The equality operator.
override